
*12345678901234567890123456789012345678901234567890123456789012345678901234567890


*	************************************************************************
* 	File-Name: 	SurveyCoding.do
*	Log-file:	N/A
*	Date:  		07/05/2011
*	Author: 	Michal Aklin & Johannes Urpelainen
*	Input:		Original survey data: AklinUrpelainenSurveyData.dta
*	Output:		SurveyReplication.dta
*	Purpose:   	.do file to create the SurveyReplication.dta dataset
*	************************************************************************

*	************************************************************************
*	1. Call up the data
*	************************************************************************

clear all
set more off
use "AklinUrpelainenSurveyData.dta"

*	************************************************************************
*	2. Recode data and create variables
*		Variables:
*
*		Dependent Variable
*			cuc420			Response to: 
*							"The US Congress is debating a new policy to 
*							promote clean energy, such as wind and solar power. 
*							Some people say that the policy could improve 
*							America's {TEXT A}. However, others say that the 
*							policy could also weaken {TEXT B}. From what you 
*							have heard, do you support or oppose the policy?"
*							Measures:
*							From 1 (strongly support) to 5 (strongly oppose)
*							Other values denote some issue
*
*		Treatment
*			text_CUC420a	Randomized {TEXT A}
*							"national security by reducing oil imports from 
*							the Middle East"
*							or
*							"economy by creating new jobs"
*
*			text_CUC420b	Randomized {TEXT B}
*							"national security by preventing the use of 
*							domestic coal resources"
*							or
*							"the economy by increasing energy prices"
*	************************************************************************

*	************************************************************************
*	Dependent Variable
*	************************************************************************

*	Dependent variable correction: values of 8 means that the question was
*		skipped (1 obs)
replace cuc420 = . if cuc420 == 8


*	Rename the labels (adding capital letters)
label define label_dv 1 "Strongly support" 2 "Somewhat support" 3 "Neutral" 4 "Somewhat oppose" 5 "Strongly oppose", replace
label values cuc420 label_dv

*	Dependent variable
gen cuc420_v2 = .
replace cuc420_v2 = 0 if cuc420 == 5
replace cuc420_v2 = 1 if cuc420 == 4
replace cuc420_v2 = 2 if cuc420 == 3
replace cuc420_v2 = 3 if cuc420 == 2
replace cuc420_v2 = 4 if cuc420 == 1
label variable cuc420_v2 "Support for Clean Energy Policy"
label define label_dv_v2 0 "Strongly oppose" 1 "Somewhat oppose" 2 "Neutral" 3 "Somewhat support" 4 "Strongly support", replace
label values cuc420_v2 label_dv_v2


*	************************************************************************
*	Independent Variable
*	************************************************************************

*	Treatment
gen jobs_plus = 0
replace jobs_plus = 1 if text_CUC420a == "economy by creating new jobs"

gen security_plus = 0
replace security_plus = 1 if text_CUC420a == "national security by reducing oil imports from the Middle East"

gen prices_minus = 0
replace prices_minus = 1 if text_CUC420b == "the economy by increasing energy prices"

gen security_minus = 0
replace security_minus = 1 if text_CUC420b == "national security by preventing the use of domestic coal resources"

*	Generate a total_v1 variable to verify that the coding is correct
*		(should only contain 2's and 0's) (0's indicate missing responses)
egen total_v1 =  rowtotal(jobs_plus security_plus prices_minus security_minus)
sum total_v1

*	Generate the treatment categories
gen treatment1 = .
replace treatment1 = 1 if jobs_plus == 1 & prices_minus == 1
replace treatment1 = 2 if jobs_plus == 1 & security_minus == 1
replace treatment1 = 3 if security_plus == 1 & prices_minus == 1
replace treatment1 = 4 if security_plus == 1 & security_minus == 1

label define label_treatment 1 "Econ+ Econ-" 2 "Econ+ Sec-" 3 "Sec+ Econ-" 4 "Sec+ Sec-"
label values treatment1 label_treatment

gen treatdummy1 = 0
replace treatdummy1 = 1 if treatment1 == 1
label variable treatdummy1 "Econ+, Econ-"

gen treatdummy2 = 0
replace treatdummy2 = 1 if treatment1 == 2
label variable treatdummy2 "Econ+, Sec-"

gen treatdummy3 = 0
replace treatdummy3 = 1 if treatment1 == 3
label variable treatdummy3 "Sec+, Econ-"

gen treatdummy4 = 0
replace treatdummy4 = 1 if treatment1 == 4
label variable treatdummy4 "Sec+, Sec-"




*	************************************************************************
*	Control Variables
*	************************************************************************


*	Religion dummy
gen religious = .
replace religious = 1 if v216 == 1
replace religious = 0 if v216 > 1 & v216 != .

*	Conservative
gen conservative = .
replace conservative = 1 if v243 == 4 | v243 == 5
replace conservative = 0 if v243 == 1 | v243 == 2 
label variable conservative "Conservative"

gen ideology = .
replace ideology = -1 if v243 == 4 | v243 == 5
replace ideology = 0 if v243 == 3
replace ideology = 1 if v243 == 1 | v243 == 2


*	Education
gen educ = .
replace educ = 0 if v213 == 1 | v213 == 2 | v213 == 3
replace educ = 1 if v213 == 4 | v213 == 5 | v213 == 6
label variable educ `"Education"'

*	Income
gen income = .
replace income = v246 if v246 < 15
label variable income `"Income"'

*	Gender
gen female = .
replace female = 1 if v208 == 2
replace female = 0 if v208 == 1


*	Global warming
gen globalwarming = .
replace globalwarming = 1 if cuc320 == 1
replace globalwarming = 0 if cuc320 == 2 | cuc320 == 3
label variable globalwarming `"Global Warming"'


*	Missing data
gen missing420 = 0
replace missing420 = 1 if cuc420 == .
label variable missing420 `"Missing Obs (dep. var.)"'


*	************************************************************************
*	3. Save the data
*	************************************************************************

set cformat %8.3f
save "SurveyReplication.dta", replace
